@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2019 Luis Falcon <falcon@gnu.org>
+#    Copyright (C) 2011-2019 Luis Falcon <falcon@gnuhealth.org>
 #    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
 #    Copyright (C) 2011 Cédric Krier
 
@@ -32,7 +32,7 @@ info = dict(config.items('tryton'))
 for key in ('depends', 'extras_depend', 'xml'):
     if key in info:
         info[key] = info[key].strip().splitlines()
-major_version, minor_version = 4, 6
+major_version, minor_version = 5, 0
 
 requires = []
 
@@ -55,7 +55,7 @@ setup(name='gnuhealth_genetics_uniprot',
     description=info.get('description', 'GNU Health Genetics UNIPROT Data'),
     author=info.get('author', 'GNU Solidario'),
     author_email=info.get('email', 'health@gnusolidario.org'),
-    url=info.get('website', 'http://health.gnu.org/'),
+    url=info.get('website', 'https://www.gnuhealth.org/'),
     download_url='http://ftp.gnu.org/gnu/health/',
     package_dir={'trytond.modules.health_genetics_uniprot': '.'},
     packages=[
