@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2018 Luis Falcon <falcon@gnu.org>
+#    Copyright (C) 2011-2019 Luis Falcon <falcon@gnuhealth.org>
 #    Copyright (C) 2011 Cédric Krier
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ info = dict(config.items('tryton'))
 for key in ('depends', 'extras_depend', 'xml'):
     if key in info:
         info[key] = info[key].strip().splitlines()
-major_version, minor_version = 4, 6
+major_version, minor_version = 5, 0
 
 requires = []
 
@@ -54,7 +54,7 @@ setup(name='gnuhealth_history',
     long_description=read('README'),
     author='GNU Solidario',
     author_email='health@gnusolidario.org',
-    url='http://health.gnu.org',
+    url='https://www.gnuhealth.org',
     download_url='http://ftp.gnu.org/gnu/health/',
     package_dir={'trytond.modules.health_history': '.'},
     packages=[
